[FFmpeg-cvslog] r25235 - in trunk/libavfilter: avfilter.c avfilter.h

stefano subversion
Mon Sep 27 23:57:16 CEST 2010


Author: stefano
Date: Mon Sep 27 23:57:16 2010
New Revision: 25235

Log:
Use more expressive names for the avfilter_insert_filter() in and out
parameters.

Modified:
   trunk/libavfilter/avfilter.c
   trunk/libavfilter/avfilter.h

Modified: trunk/libavfilter/avfilter.c
==============================================================================
--- trunk/libavfilter/avfilter.c	Mon Sep 27 23:50:26 2010	(r25234)
+++ trunk/libavfilter/avfilter.c	Mon Sep 27 23:57:16 2010	(r25235)
@@ -122,7 +122,7 @@ int avfilter_link(AVFilterContext *src, 
 }
 
 int avfilter_insert_filter(AVFilterLink *link, AVFilterContext *filt,
-                           unsigned in, unsigned out)
+                           unsigned filt_srcpad_idx, unsigned filt_dstpad_idx)
 {
     int ret;
     unsigned dstpad_idx = link->dstpad - link->dst->input_pads;
@@ -132,7 +132,7 @@ int avfilter_insert_filter(AVFilterLink 
            filt->name, link->src->name, link->dst->name);
 
     link->dst->inputs[dstpad_idx] = NULL;
-    if ((ret = avfilter_link(filt, out, link->dst, dstpad_idx)) < 0) {
+    if ((ret = avfilter_link(filt, filt_dstpad_idx, link->dst, dstpad_idx)) < 0) {
         /* failed to link output filter to new filter */
         link->dst->inputs[dstpad_idx] = link;
         return ret;
@@ -140,14 +140,14 @@ int avfilter_insert_filter(AVFilterLink 
 
     /* re-hookup the link to the new destination filter we inserted */
     link->dst = filt;
-    link->dstpad = &filt->input_pads[in];
-    filt->inputs[in] = link;
+    link->dstpad = &filt->input_pads[filt_srcpad_idx];
+    filt->inputs[filt_srcpad_idx] = link;
 
     /* if any information on supported media formats already exists on the
      * link, we need to preserve that */
     if (link->out_formats)
         avfilter_formats_changeref(&link->out_formats,
-                                   &filt->outputs[out]->out_formats);
+                                   &filt->outputs[filt_dstpad_idx]->out_formats);
 
     return 0;
 }

Modified: trunk/libavfilter/avfilter.h
==============================================================================
--- trunk/libavfilter/avfilter.h	Mon Sep 27 23:50:26 2010	(r25234)
+++ trunk/libavfilter/avfilter.h	Mon Sep 27 23:57:16 2010	(r25235)
@@ -783,12 +783,12 @@ void avfilter_destroy(AVFilterContext *f
  *
  * @param link the link into which the filter should be inserted
  * @param filt the filter to be inserted
  * @param in   the input pad on the filter to connect
  * @param out  the output pad on the filter to connect
  * @return     zero on success
  */
 int avfilter_insert_filter(AVFilterLink *link, AVFilterContext *filt,
-                           unsigned in, unsigned out);
+                           unsigned filt_srcpad_idx, unsigned filt_dstpad_idx);
 
 /**
  * Insert a new pad.
@@ -783,12 +783,12 @@ void avfilter_destroy(AVFilterContext *f
  * @param link the link into which the filter should be inserted
  * @param filt the filter to be inserted
- * @param in   the input pad on the filter to connect
- * @param out  the output pad on the filter to connect
+ * @param filt_srcpad_idx the input pad on the filter to connect
+ * @param filt_dstpad_idx the output pad on the filter to connect
  * @return     zero on success
  */



More information about the ffmpeg-cvslog mailing list